@@ -39,7 +39,7 @@ class PolyphonicKeyPressure(MIDIMessage):
         self.pressure = pressure
         super().__init__(channel=channel)
         if not 0 <= self.note <= 127 or not 0 <= self.pressure <= 127:
-            raise self._EX_VALUEERROR_OOR
+            self._raise_valueerror_oor()
 
     def __bytes__(self):
         return bytes(
